﻿//DESCRIPTION: Convert endnotes to blind notes
// Peter Kahrel

(function () {	

	var styleName = 'Blind note reference';
	var indd = app.documents[0];
	
	var xrefFormat = getXrefFormat();
	var hideStyle = getHideStyle();

	var target, source;
	var notes = indd.stories.everyItem().endnotes.everyItem().getElements();
	
	
	function getXrefFormat () {
		
		//------------------------------------
		// Get the format strings from the user
		
		function getFormat () {
			var w = new Window ('dialog {text: "Blind notes"}');
				w.panel = w.add ('panel {alignChildren: "right"}');

				w.g1 = w.panel.add ('group')
					w.g1.add ('statictext {text: "Text before:"}');
					w.g1.textBefore = w.g1.add ('edittext {preferredSize: [100,-1]}');

				w.g2 = w.panel.add ('group')
					w.g2.add ('statictext {text: "Text after:"}');
					w.g2.textAfter = w.g2.add ('edittext {preferredSize: [100,-1]}');
					
				w.g3 = w.panel.add ('group')
					w.g3.add ('statictext {text: "Character style:"}');
					w.g3.style = w.g3.add ('dropdownlist', undefined, app.documents[0].characterStyles.everyItem().name);
					w.g3.style.preferredSize = [100,-1];

				w.buttons = w.add ('group');
					w.buttons.add ('button {text: "Cancel"}');
					w.buttons.add ('button {text: "OK"}');
					
				w.onShow = function () {
					w.g1.textBefore.active = true;
					w.g3.style.selection = 0;
				}

			if (w.show() == 2) {  // User clicked Cancel
				exit();
			}
			
			return {
				textBefore: w.g1.textBefore.text,
				textAfter: w.g2.textAfter.text,
				cstyleName: w.g3.style.selection.text,
			}
		}

		//-----------------------------------------------
		
		var cr = indd.crossReferenceFormats.item (styleName);
		if (!cr.isValid) {
			var format = getFormat();
			cr = indd.crossReferenceFormats.add ({
				name: styleName,
			});
			cr.buildingBlocks.add (BuildingBlockTypes.CUSTOM_STRING_BUILDING_BLOCK, undefined, format.textBefore);
			cr.buildingBlocks.add (BuildingBlockTypes.PAGE_NUMBER_BUILDING_BLOCK);
			cr.buildingBlocks.add (BuildingBlockTypes.CUSTOM_STRING_BUILDING_BLOCK, undefined, format.textAfter);
			if (format.cstyleName != indd.characterStyles[0].name) {
				cr.appliedCharacterStyle = indd.characterStyles.item (format.cstyleName);
			}
		}
		return cr;
	}

	function getHideStyle () {
		var cstyle = indd.characterStyles.item (styleName);
		if (!cstyle.isValid) {
			cstyle = indd.characterStyles.add ({
				name: styleName,
				pointSize: 0.1,
				horizontalScale: 1,
			});
			try {
				cstyle.fillColor = 'None';
			} catch (_) {
			}
		}
		return cstyle;
	}

	//----------------------------------------------------------------------
	
	if (notes.length === 0) {
		alert ('This document contains no endnotes');
		exit();
	}

	// Set up a few things

	indd.endnoteOptions.endnoteSeparatorText = '';
	indd.endnoteOptions.endnoteMarkerStyle = hideStyle;

	for (var i = notes.length-1; i >= 0; i--) {
		// Skip notes that were done previously
		if (notes[i].characters[1].findHyperlinks().length > 0) {
			continue;
		}
		notes[i].characters[0].appliedCharacterStyle = hideStyle;
		target = indd.hyperlinkTextDestinations.add (notes[i].storyOffset);
		source = indd.crossReferenceSources.add (notes[i].insertionPoints[0], xrefFormat);
		indd.hyperlinks.add (source, target);
	}

}());